/*
 *   Copyright (C) 2008 Dmitry Suzdalev <dimsuz@gmail.com>
 *
 * This program is free software you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef MAIN_WIDGET_H
#define MAIN_WIDGET_H

#include <plasma/dataengine.h>
#include <plasma/containment.h>

namespace Plasma
{
    class Label;
    class Icon;
    class PanelSvg;
}

class NotificationWidget;
class QGraphicsLinearLayout;

/**
 * Main widget of an applet which acts as a container of notification widgets
 */
class MainWidget : public Plasma::Containment
{
    Q_OBJECT
public:
    MainWidget(QGraphicsItem* parent = 0);
    ~MainWidget();

    virtual void paint ( QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget = 0 );

    void handleNewData( const Plasma::DataEngine::Data &data );
    void removeNotification(uint id);

    int notificationCount() const;

    /**
     * Returns mask of opaque areas of this widget
     */
    QBitmap widgetMask() const;

    // reimplement these from Containment and make them empty
    // as we don't need any of its saving/loading stuff
    // to be triggered
    virtual void save(KConfigGroup&) const {}
    virtual void restore(KConfigGroup&) {}

signals:
    // emmitted when number of child widget changes
    void widgetCountChanged();

private slots:
    void onActionInvoked( uint id, uint actionId );

private:
    void resizeEvent(QGraphicsSceneResizeEvent* event);

    void updateWidgetSize();
    NotificationWidget* findWidgetById(uint id);

private:
    // appName => widget
    QHash<QString,NotificationWidget*> m_notifyWidgets;

    QGraphicsLinearLayout* m_layout;

    Plasma::Label* m_introLabel;
    Plasma::PanelSvg* m_panelSvg;
};

#endif
