/*
 *   Copyright (C) 2008 Dmitry Suzdalev <dimsuz@gmail.com>
 *
 * This program is free software you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/
#include <QGraphicsItem>
#include <QHash>

class QTextDocument;

/**
 * Graphics item for holding single notification text and its actions
 */
class NotifyTextItem : public QObject, public QGraphicsItem
{
    Q_OBJECT
public:
    NotifyTextItem(QGraphicsItem* parent=0);
    ~NotifyTextItem();

    virtual QRectF boundingRect() const;
    virtual void paint(QPainter* painter, const QStyleOptionGraphicsItem *option, QWidget* widget = 0);

    // you can get it back with boundingRect()
    void setItemSize(qreal width, qreal height);

    void setId(uint id) { m_id = id; }
    uint id() const { return m_id; }

    // if summary is empty will extract first string from it and set
    void setNotificationText(const QString& appName, const QString& summary, const QString& body);
    QString body() const;
    QString summary() const { return m_summary; }

    void setActions(const QStringList& actions);

    void setTimeout(int timeout) { m_timeout = timeout; }
    int timeout() const { return m_timeout; }

signals:
    void actionInvoked(uint nId, uint actId);

private:
    void updateActionRects();

    void mousePressEvent(QGraphicsSceneMouseEvent*);
    void mouseReleaseEvent(QGraphicsSceneMouseEvent*);
    void hoverMoveEvent(QGraphicsSceneHoverEvent*);

private:
    QTextDocument* m_bodyTextDoc;

    uint m_id;
    QString m_summary;

    struct ActionInfo
    {
        uint actId;
        QString actName;
        QRectF actRect;
        ActionInfo(uint id = 0, const QString& name = QString(), const QRectF& r = QRectF() )
            : actId(id), actName(name), actRect(r) {}
    };

    QList<ActionInfo> m_actions;

    int m_timeout;

    QSizeF m_size;

    uint m_hoveredActId;
};
